==> jc-1.4.0.tar.gz: soot/javaToJimple/NestedClassListBuilder.h <==
// public class soot.javaToJimple.NestedClassListBuilder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class a4c08590bba11c21 soot_javaToJimple_NestedClassListBuilder

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_NestedClassListBuilder_H_
#define _JC_soot_javaToJimple_NestedClassListBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_refs	_jc_soot_javaToJimple_NestedClassListBuilder$sub_refs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs	_jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$refs	_jc_soot_javaToJimple_NestedClassListBuilder$refs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$nonrefs	_jc_soot_javaToJimple_NestedClassListBuilder$nonrefs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$object	_jc_soot_javaToJimple_NestedClassListBuilder$object;

typedef const struct _jc_soot_javaToJimple_NestedClassListBuilder$vmethods	_jc_soot_javaToJimple_NestedClassListBuilder$vmethods;
typedef const struct _jc_soot_javaToJimple_NestedClassListBuilder$vtable	_jc_soot_javaToJimple_NestedClassListBuilder$vtable;
typedef const struct _jc_soot_javaToJimple_NestedClassListBuilder$vtype	_jc_soot_javaToJimple_NestedClassListBuilder$vtype;

// Constructors
extern void _jc_soot_javaToJimple_NestedClassListBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_soot_javaToJimple_NestedClassListBuilder$method$enter$0698e71b16532e07(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_NestedClassListBuilder$method$getAnonClassBodyList$ad33e69c969b3cf2(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *);
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_NestedClassListBuilder$method$getClassDeclsList$fa7492f28f0564e5(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_NestedClassListBuilder$method_info$enter$0698e71b16532e07;
extern _jc_method _jc_soot_javaToJimple_NestedClassListBuilder$method_info$getAnonClassBodyList$ad33e69c969b3cf2;
extern _jc_method _jc_soot_javaToJimple_NestedClassListBuilder$method_info$getClassDeclsList$fa7492f28f0564e5;

// Virtual methods structure
struct _jc_soot_javaToJimple_NestedClassListBuilder$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$0698e71b16532e07)(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *, struct _jc_object *, struct _jc_object *);
	struct _jc_java_util_ArrayList$object	*(*getAnonClassBodyList$ad33e69c969b3cf2)(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *);
	struct _jc_java_util_ArrayList$object	*(*getClassDeclsList$fa7492f28f0564e5)(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *);
};

// Vtable
struct _jc_soot_javaToJimple_NestedClassListBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_NestedClassListBuilder$vmethods	soot_javaToJimple_NestedClassListBuilder;
};

// Vtype
struct _jc_soot_javaToJimple_NestedClassListBuilder$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_NestedClassListBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_refs {
	struct _jc_java_util_ArrayList$object	*classDeclsList;
	struct _jc_java_util_ArrayList$object	*anonClassBodyList;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_NestedClassListBuilder$refs {
    _jc_soot_javaToJimple_NestedClassListBuilder$sub_refs	soot_javaToJimple_NestedClassListBuilder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_NestedClassListBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs	soot_javaToJimple_NestedClassListBuilder;
};

// Object instance structure
struct _jc_soot_javaToJimple_NestedClassListBuilder$object {
	_jc_soot_javaToJimple_NestedClassListBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_NestedClassListBuilder$vtype	*vtype;
	_jc_soot_javaToJimple_NestedClassListBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_NestedClassListBuilder$vtype _jc_soot_javaToJimple_NestedClassListBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_NestedClassListBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_NestedClassListBuilder$class_object;

#endif	/* _JC_soot_javaToJimple_NestedClassListBuilder_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/NestedClassListBuilder.h <==
// public class soot.javaToJimple.NestedClassListBuilder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class a4c08590bba11c21 soot_javaToJimple_NestedClassListBuilder

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_NestedClassListBuilder_H_
#define _JC_soot_javaToJimple_NestedClassListBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_refs	_jc_soot_javaToJimple_NestedClassListBuilder$sub_refs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs	_jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$refs	_jc_soot_javaToJimple_NestedClassListBuilder$refs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$nonrefs	_jc_soot_javaToJimple_NestedClassListBuilder$nonrefs;
typedef struct _jc_soot_javaToJimple_NestedClassListBuilder$object	_jc_soot_javaToJimple_NestedClassListBuilder$object;

typedef const struct _jc_soot_javaToJimple_NestedClassListBuilder$vmethods	_jc_soot_javaToJimple_NestedClassListBuilder$vmethods;
typedef const struct _jc_soot_javaToJimple_NestedClassListBuilder$vtable	_jc_soot_javaToJimple_NestedClassListBuilder$vtable;
typedef const struct _jc_soot_javaToJimple_NestedClassListBuilder$vtype	_jc_soot_javaToJimple_NestedClassListBuilder$vtype;

// Constructors
extern void _jc_soot_javaToJimple_NestedClassListBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_soot_javaToJimple_NestedClassListBuilder$method$enter$0698e71b16532e07(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_NestedClassListBuilder$method$getAnonClassBodyList$ad33e69c969b3cf2(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_NestedClassListBuilder$method$getClassDeclsList$fa7492f28f0564e5(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_NestedClassListBuilder$method_info$enter$0698e71b16532e07;
extern _jc_method _jc_soot_javaToJimple_NestedClassListBuilder$method_info$getAnonClassBodyList$ad33e69c969b3cf2;
extern _jc_method _jc_soot_javaToJimple_NestedClassListBuilder$method_info$getClassDeclsList$fa7492f28f0564e5;

// Virtual methods structure
struct _jc_soot_javaToJimple_NestedClassListBuilder$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$0698e71b16532e07)(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_util_ArrayList$object	*(*getAnonClassBodyList$ad33e69c969b3cf2)(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_ArrayList$object	*(*getClassDeclsList$fa7492f28f0564e5)(_jc_env *, struct _jc_soot_javaToJimple_NestedClassListBuilder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_NestedClassListBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_NestedClassListBuilder$vmethods	soot_javaToJimple_NestedClassListBuilder;
};

// Vtype
struct _jc_soot_javaToJimple_NestedClassListBuilder$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_NestedClassListBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_refs {
	struct _jc_java_util_ArrayList$object	*classDeclsList;
	struct _jc_java_util_ArrayList$object	*anonClassBodyList;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_NestedClassListBuilder$refs {
    _jc_soot_javaToJimple_NestedClassListBuilder$sub_refs	soot_javaToJimple_NestedClassListBuilder;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_NestedClassListBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_NestedClassListBuilder$sub_nonrefs	soot_javaToJimple_NestedClassListBuilder;
};

// Object instance structure
struct _jc_soot_javaToJimple_NestedClassListBuilder$object {
	_jc_soot_javaToJimple_NestedClassListBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_NestedClassListBuilder$vtype	*vtype;
	_jc_soot_javaToJimple_NestedClassListBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_NestedClassListBuilder$vtype _jc_soot_javaToJimple_NestedClassListBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_NestedClassListBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_NestedClassListBuilder$class_object;

#endif	/* _JC_soot_javaToJimple_NestedClassListBuilder_H_ */
